class TagType:
    EXTERNAL_ID = 'ExternalId='
    DISPLAY_NAME = 'DisplayName='
    LINKS = 'Links='
    TITLE = 'Title='
    WORK_ITEM_IDS = 'WorkItemIds='
    DESCRIPTION = 'Description='
    LABELS = 'Labels='
